==============
Requirements
==============

``camrcs`` requires a Unix-based operation system with Python 3 and Bash installed. The Python dependencies will be installed during installation with `pip`. The only non-Python dependency is `pigz <https://zlib.net/pigz/>`_. 

